Step 2: Setting up Google Cloud Platform
========================================

Overview
^^^^^^^^

Google Cloud Platform is a service that hosts your data and web page.
This allows anyone with the link to access your webpage. 
In this section, we will upload your data to the google cloud platform 
and set up your account so that dataspectra knows where the web page should 
be sent to. 

Requirements
^^^^^^^^^^^^

 * A Google account

Creating a Google Cloud Platform account
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
- Go to: https://cloud.google.com/
- Click CONSOLE in the upper right corner
- Agree to the Terms of Service

- Click "Select a project"
- Click on the "+" bar to the top
- Give it a unique name.  (> 4 characters)
    - As you type a name in, you will see a statement below that says (Your project ID will be xxxx). This may include numbers. 
 - Tip, if this name is long and unique enough, you won't have to get numbers added aftewrards. 
 - For demonstration purposes, I am naming mine dataspectrademo

- It takes time for the project to fully activate, so we will continue onto different steps before. 

Installing the Google Cloud Software Development Kit (SDK)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. Open a new window and download the google-cloud-SDK from the following link:

https://cloud.google.com/sdk/docs/

2. Extract the package by double clicking the downloaded *.tar.gz file. 
3. Move the folder to your Desktop. 
4. Open Terminal, found in Applications --> Utilities --> and type

::
    ~/Desktop/google-cloud-sdk/install.sh

5. Press Return, and continue to press Return. 

The output should look something like this:
::


Activating the Google App Engine
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

1. Go to console.cloud.google.com 
2. Click on Datastore. 
3. Activating datastore.
4. Click on Create an Entity. 
5. Click on "Your first entity"
6. Choose the region where you website will most likely be used. 
7. Wait. 
8.  Click on AppEngine to activate it. 
9.  Activate budget by clicking. 

Authenticating the Google App Engine
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

https://cloud.google.com/docs/authentication/getting-started
1. Go to console.cloud.google.com
2. Click on the Menu at the top left. 
Go to APIs & Services
Click on the Key in the left side bar. 
Click on the "create service account key"
Put any name down.  
- Then specify Role Owner
Click on create.
Move the file to your google-cloud-sdk folder. 
Type in export GOOGLE_APPLICATION_CREDENTIALS="/..

Step 10: #Authenticate your login
gcloud auth login
